@@ -58,7 +58,7 @@ class ClinicalQualityMeasure123v6(DiabetesQualityMeasure):
     denominator of this measure; patients with a diagnosis of secondary diabetes due to another
     condition should not be included.
 
-    More information: https://ecqi.healthit.gov/ecqm/measures/cms123v6
+    More information: https://ecqi.healthit.gov/sites/default/files/ecqm/measures/CMS123v6.html
     """
 
     class Meta:
@@ -69,7 +69,7 @@ class ClinicalQualityMeasure123v6(DiabetesQualityMeasure):
         description = (
             'Patients 18-75 years of age with diabetes who have not received a foot exam in the last year.'  # noqa: E501
         )
-        information = 'https://ecqi.healthit.gov/ecqm/measures/cms123v6'
+        information = 'https://ecqi.healthit.gov/sites/default/files/ecqm/measures/CMS123v6.html'
 
         identifiers = ['CMS123v6']
 
