@@ -189,6 +189,20 @@ class PatientRecordSet:
 
         return self.__class__(items)
 
+    def _enumerate_system_codes(self, item):
+        """
+        Returns systems, and code from a coding.
+        Eg: ['icd10cm', 'icd10pcs'], E119
+        """
+        # not all patient record data has codes, ex: referrals
+        if not self.VALID_SYSTEMS:
+            raise Exception('Invalid call to find() on non-coded patient data.')
+
+        for coding in self.item_to_codes(item):
+            coding_systems = SYSTEM_CODE_MAPPING.get(coding['system'], [])
+            for coding_system in coding_systems:
+                yield coding_systems, coding.get('code')
+
     def _enumerate_system_list_codes(self, value_set):
         # not all patient record data has codes, ex: referrals
         if not self.VALID_SYSTEMS:
@@ -264,6 +278,29 @@ class PatientRecordSet:
             ]
         return queryset
 
+    def find_code(self, *args, **kwargs):
+        """
+        In development.
+        Not for external use.
+
+        Returns matching records by code system and code, for when a ValueSet is not available.
+        Ex: patient.conditions.find_code(icd10cm="E119")
+        """
+        queryset = self.__class__(self.records)
+
+        def filter_fn(record):
+            for codings, code in self._enumerate_system_codes(record):
+                for key, value in kwargs.items():
+                    if key.lower() in codings and code.upper() == value.upper():
+                        return True
+            return False
+
+        queryset.records = [
+            record for record in queryset if filter_fn(record)
+        ]
+
+        return queryset
+
     def find(self, value_set):
         """
         Find records that match a given value_set based on exact code. Returns a
@@ -442,7 +479,7 @@ class PatientPeriodRecordSet(PatientRecordSet):
 
 
 class BillingLineItemRecordSet(PatientEventRecordSet):
-    VALID_SYSTEMS = ['cpt', 'hcpcs']
+    VALID_SYSTEMS = ['cpt', 'hcpcs', 'snomedct']
     DATE_FIELD = 'created'
     PATIENT_FIELD = 'billing_line_items'
     API_UPDATE_FIELD = 'billingLineItems'
@@ -656,6 +693,7 @@ class ImagingReportRecordSet(PatientEventRecordSet):
             })
         return codes
 
+
 class PrescriptionRecordSet(PatientRecordSet):
     VALID_SYSTEMS = [
         'rxnorm',
@@ -748,6 +786,7 @@ class AllergyIntoleranceRecordSet(PatientEventRecordSet):
     API_UPDATE_FIELD = 'allergyIntolerances'
     DATE_FIELD = 'onsetDate'
 
+
 class AdministrativeDocumentRecordSet(PatientEventRecordSet):
     VALID_SYSTEMS: List[str] = ['canvas', 'internal']
     PATIENT_FIELD = 'administrative_documents'
